@@ -1,14 +1,35 @@
+from __future__ import annotations
+
 import sys
 
 from matplotlib.pyplot import style as plt_style
 
 # Short cut to all styles
 from .alice import ALICE
-from .atlas import ATLAS
-from .atlas import ATLASAlt
-from .atlas import ATLASTex
-from .cms import CMS, CMSTex, ROOT, ROOTTex
-from .lhcb import LHCb, LHCbTex, LHCb1, LHCbTex1, LHCb2, LHCbTex2
+from .atlas import ATLAS, ATLASAlt, ATLASTex
+from .cms import CMS, ROOT, CMSTex, ROOTTex
+from .lhcb import LHCb, LHCb1, LHCb2, LHCbTex, LHCbTex1, LHCbTex2
+
+__all__ = (
+    "ALICE",
+    "ATLAS",
+    "ATLASAlt",
+    "ATLASTex",
+    "CMS",
+    "ROOT",
+    "CMSTex",
+    "ROOTTex",
+    "LHCb",
+    "LHCb1",
+    "LHCb2",
+    "LHCbTex",
+    "LHCbTex1",
+    "LHCbTex2",
+    "set_style",
+    "fira",
+    "firamath",
+    "fabiola",
+)
 
 
 def set_style(styles):
